boofun.core.query\_model
==========================

.. automodule:: boofun.core.query_model


   .. rubric:: Functions

   .. autosummary::

      check_query_safety
      get_access_type
      safe_alternatives

   .. rubric:: Classes

   .. autosummary::

      AccessType
      QueryModel

   .. rubric:: Exceptions

   .. autosummary::

      ExplicitEnumerationError
      QuerySafetyWarning
